##############
Acknowledgment
##############

This work was developed during the research project "MINLP-Optimization of Design and Operation of Complex Energy Systems", 
funded by the German Federal Ministry for Economic Affairs and Energy (project reference number 03ET4053A). 
The funding is gratefully acknowledged.

The developers of *aristopy* also want to thank the developer groups of the open-source packages 
`FINE <https://github.com/FZJ-IEK3-VSA/FINE>`_, `oemof <https://github.com/oemof>`_, `tsam <https://github.com/FZJ-IEK3-VSA/tsam>`_, 
and `pvlib <https://github.com/pvlib/pvlib-python>`_.
We learned a lot from these packages during the development of *aristopy* and had the opportunity to adapt selected code elements.
These packages greatly contribute to the open-source community, and they are worth looking at more closely.

.. image:: misc/bmwi_logo.png
    :target: https://www.energietechnik.tu-berlin.de/menue/forschung/energiesystemanalyse_und_optimierung/oeb_ensys/
    :width: 200px
    :alt: BMWi Logo
    :align: left
